"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthProvider = void 0;
const axios_1 = require("axios");
const fns_api_1 = require("fns-api");
class AuthProvider {
    constructor(options) {
        this.clientSecret = options.clientSecret;
        let loginApi = options.loginApi;
        if (!loginApi) {
            let axiosInstance = options.axios;
            if (!axiosInstance) {
                axiosInstance = axios_1.default.create({
                    baseURL: fns_api_1.BASE_URL,
                    headers: fns_api_1.defaultHeaders
                });
            }
            loginApi = new fns_api_1.LoginApi(axiosInstance);
        }
        this.loginApi = loginApi;
    }
    refreshTokens() {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.loginApi.refreshTokens({
                refresh_token: this.refreshToken,
                client_secret: this.clientSecret
            });
            this.accessToken = data.sessionId;
            this.refreshToken = data.refresh_token;
        });
    }
    getAccessToken() {
        return this.accessToken;
    }
    getRefreshToken() {
        return this.refreshToken;
    }
    clearTokens() {
        this.accessToken = undefined;
        this.refreshToken = undefined;
    }
}
exports.AuthProvider = AuthProvider;
