"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Client = void 0;
const axios_1 = require("axios");
const axios_auth_refresh_1 = require("axios-auth-refresh");
const fns_api_1 = require("fns-api");
const auth_intercepter_1 = require("./auth.intercepter");
class Client {
    constructor(options) {
        this.auth = options.auth;
        let receiptApi = options.receiptApi;
        if (!receiptApi) {
            let axiosInstance = options.axios;
            if (!axiosInstance) {
                axiosInstance = axios_1.default.create({
                    baseURL: fns_api_1.BASE_URL,
                    headers: fns_api_1.defaultHeaders
                });
            }
            (0, auth_intercepter_1.createAuthTokenIntercepter)(axiosInstance, this.auth);
            (0, axios_auth_refresh_1.default)(axiosInstance, () => this.auth.refreshTokens());
            receiptApi = new fns_api_1.ReceiptApi(axiosInstance);
        }
        this.receiptApi = receiptApi;
    }
    addReceipt(fiscalDataOrQR, cancelToken) {
        return __awaiter(this, void 0, void 0, function* () {
            if (typeof fiscalDataOrQR === 'string') {
                const response = yield this.receiptApi.addReceiptQR({ qr: fiscalDataOrQR }, cancelToken);
                return response.data;
            }
            else {
                const response = yield this.receiptApi.addReceipt({ fiscalData: fiscalDataOrQR, sendToEmail: false }, cancelToken);
                return response.data;
            }
        });
    }
    getReceipt(id, cancelToken) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.receiptApi.getReceipt(id, cancelToken);
            return response.data;
        });
    }
    getReceipts(cancelToken) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.receiptApi.getReceipts(cancelToken);
            return response.data;
        });
    }
    removeReceipt(id, cancelToken) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.receiptApi.removeReceipt(id, cancelToken);
        });
    }
}
exports.Client = Client;
